# [1.8.0](https://github.com/seriaati/ambr/compare/v1.7.16..v1.8.0) - 2024-11-29

## Bug Fixes

- Fix value of SpecialStat.ENERGY_RECHARGE - ([c681a92](https://github.com/seriaati/ambr/commit/c681a92679fa61529ceebc40391c499cc46d9dce))
- Fix default value for list fields - ([c4cc4de](https://github.com/seriaati/ambr/commit/c4cc4de31ac64e09c3fe281cf8697a10c23a0f4c))

## Features

- Use loguru for logging - ([474c812](https://github.com/seriaati/ambr/commit/474c812bc4bea3b49abd2e13154b52eb17828b48))
- Add fetch_character_guide method - ([a791e74](https://github.com/seriaati/ambr/commit/a791e7477c93e582a046d8f887517c30ec94d7f8))

## Improvements

- Enumify WeaponType and SpecialStat - ([719c643](https://github.com/seriaati/ambr/commit/719c643b7e0796e234fb949f9df9b0e45c8147cc))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#76](https://github.com/seriaati/ambr/issues/76)) - ([b56a4c9](https://github.com/seriaati/ambr/commit/b56a4c994f01adb9e61d0a87c5c18c4f380994c8))
- **(ruff)** Ignore ALL rules in test.py - ([df0f032](https://github.com/seriaati/ambr/commit/df0f032936b244aa4abe2741b2ee5a8661216ce2))
- Add .python-version file - ([5a54037](https://github.com/seriaati/ambr/commit/5a540378e99bef2cbdf3da718ea3fdfa8c824529))

## Refactoring

- Remove pytest.mark.asyncio - ([aff8c4b](https://github.com/seriaati/ambr/commit/aff8c4be64b57942fbc58cff539a0dfcb5da17e3))
- Move enums from models.character.py to enums.py - ([cc1cd27](https://github.com/seriaati/ambr/commit/cc1cd27274e46433bd547147067a1001d80cf9d4))

